# utils.py
import os
import logging
from optparse import OptionParser
from typing import List, Dict

# 从dpkg list中统一移除那些文件特殊的标识
REMOVE_FILES_LIST = ["/."]

def classify_list_paths(list_file_path):
    if not os.path.exists(list_file_path):
        logging.info("dpkg list file is not exists: %s", list_file_path)
        return []
    
    with open(list_file_path, 'r') as f:
        paths = [line.strip() for line in f if line.strip()]
    all_paths = set(paths)
    dir_paths = set()

    for path in all_paths:
        for other in all_paths:
            if other != path and other.startswith(path.rstrip('/') + '/'):
                dir_paths.add(path)
                break
    file_paths = all_paths - dir_paths

    for file in REMOVE_FILES_LIST:
        file_paths.remove(file)

    return sorted(file_paths)

def get_versions_from_status(packages: List[str], status_file: str) -> Dict[str, str]:
    versions = {}
    current_block = ""
    found_packages = set(packages)

    if not os.path.exists(status_file):
        logging.info("Status file is not exists: %s", status_file)
        return versions
    
    with open(status_file, "r") as f:
        for line in f:
            if line.strip() == "":
                pkg_name = None
                version = None
                for entry in current_block.splitlines():
                    if entry.startswith("Package: "):
                        pkg_name = entry.split(":", 1)[1].strip()
                    elif entry.startswith("Version: "):
                        version = entry.split(":", 1)[1].strip()
                if pkg_name in found_packages:
                    versions[pkg_name] = version
                    found_packages.remove(pkg_name)
                    if not found_packages:
                        break
                current_block = ""
            else:
                current_block += line
    return versions


if __name__ == "__main__":
    parser = OptionParser()
    parser.add_option("-f", "--files",
                        action="store", type="string", dest="files",
                        help="输入需要解析的文件")
    (options, args) = parser.parse_args()

    file_paths = classify_list_paths(options.files)

    for file in file_paths:
        print(file)
